@@ -609,6 +609,7 @@ static void colourgui_connect_handlers(ColourGUI * cg)
 ColourGUI *colourgui_open(const char *scheme_name)
 {
 	ColourGUI *cg;
+	char *title;
 
 	if (!colourgui_being_edited)
 	{
@@ -632,6 +633,10 @@ ColourGUI *colourgui_open(const char *scheme_name)
 		"Colour_Scheme_Editor", NULL);
 	g_assert(cg->glade);
 	cg->widget = glade_xml_get_widget(cg->glade, "Colour_Scheme_Editor");
+	title = g_strdup_printf(_("ROXTerm Colour Scheme \"%s\""), scheme_name);
+	gtk_window_set_title(GTK_WINDOW(cg->widget), title);
+	g_free(title);
+	
 	if (!cg->orig_scheme)
 	{
 		dlg_warning(GTK_WINDOW(cg->widget),
