@@ -46,9 +46,12 @@ extern char *global_options_directory;
 extern gboolean global_options_fullscreen;
 
 /* Call after argv has been processed by gtk_init; may be called more than once
- * but repeat invocations have no effect on appdir/bindir. Bear in mind that
- * --help/--usage args will cause exit. */
-void global_options_init(int *argc, char ***argv);
+ * but repeat invocations have no effect on appdir/bindir and argv/argc are
+ * altered. Bear in mind that --help/--usage args will cause exit.
+ * If report is FALSE, parsing errors are ignored (because it gets called
+ * twice with same args if doing a dbus launch).
+ */
+void global_options_init(int *argc, char ***argv, gboolean report);
 
 /* Only access via following functions */
 extern Options *global_options;
