@@ -65,7 +65,7 @@ static char *strip_underscore(const char *in)
  * by a NULL label; use "_" for a separator, and MENUTREE_NULL_ID for any item
  * you don't want stored in item_widgets */
 static void menutree_build_shell_ap(MenuTree *menu_tree, GtkMenuShell *shell,
-		gboolean disable_shortcuts, va_list ap)
+		va_list ap)
 {
 	char *label;
 	MenuTreeID id;
@@ -89,7 +89,7 @@ static void menutree_build_shell_ap(MenuTree *menu_tree, GtkMenuShell *shell,
 			{
 				menutree_labels[id] = label;
 			}
-			if (disable_shortcuts)
+			if (menu_tree->disable_shortcuts)
 				label = strip_underscore(label);
 			switch (id)
 			{
@@ -129,7 +129,7 @@ static void menutree_build_shell_ap(MenuTree *menu_tree, GtkMenuShell *shell,
 				item = menutree_append_new_item_with_mnemonic(shell,
 						label, stock);
 			}
-			if (disable_shortcuts)
+			if (menu_tree->disable_shortcuts)
 				g_free(label);
 		}
 		if (id != MENUTREE_NULL_ID)
@@ -138,13 +138,12 @@ static void menutree_build_shell_ap(MenuTree *menu_tree, GtkMenuShell *shell,
 }
 
 /* See above for description of variable args */
-static void menutree_build_shell(MenuTree *menu_tree, GtkMenuShell * shell,
-		gboolean disable_shortcuts, ...)
+static void menutree_build_shell(MenuTree *menu_tree, GtkMenuShell * shell, ...)
 {
 	va_list ap;
 
-	va_start(ap, disable_shortcuts);
-	menutree_build_shell_ap(menu_tree, shell, disable_shortcuts, ap);
+	va_start(ap, shell);
+	menutree_build_shell_ap(menu_tree, shell, ap);
 	va_end(ap);
 }
 
@@ -199,9 +198,9 @@ menutree_set_accel_path_for_tab(MenuTree * tree, int tab)
 	char *leaf = NULL;
 	char *full_path = NULL;
 
-	if (tab >= 12)
+	if (tab >= 10)
 		return;
-	if (tree->ntabs != 1)
+	if (!tree->disable_tab_shortcuts && tree->ntabs != 1)
 	{
 		leaf = g_strdup_printf("Tabs/Select_Tab_%d", tab);
 		full_path = get_accel_path(tree->shortcuts, leaf);
@@ -416,7 +415,7 @@ void menutree_select_encoding(MenuTree *mtree, const char *encoding)
 
 /* Creates top-level menubar or popup menu with submenus */
 static void menutree_build(MenuTree *menu_tree, Options *shortcuts,
-		GType menu_type, gboolean disable_shortcuts)
+		GType menu_type)
 {
 	GtkWidget *submenu;
 
@@ -425,12 +424,11 @@ static void menutree_build(MenuTree *menu_tree, Options *shortcuts,
 	if (menu_type == GTK_TYPE_MENU_BAR)
 	{
 		menutree_build_shell(menu_tree, GTK_MENU_SHELL(menu_tree->top_level),
-				disable_shortcuts, TOP_LEVEL_MENU_ITEMS);
+				TOP_LEVEL_MENU_ITEMS);
 	}
 	else
 	{
 		menutree_build_shell(menu_tree, GTK_MENU_SHELL(menu_tree->top_level),
-			disable_shortcuts, 
 			_("_Open URL in browser"), MENUTREE_OPEN_IN_BROWSER,
 			_("_Send email"), MENUTREE_OPEN_IN_MAILER,
 			_("_Copy address to clipboard"), MENUTREE_COPY_URI,
@@ -439,7 +437,6 @@ static void menutree_build(MenuTree *menu_tree, Options *shortcuts,
 
 	submenu = gtk_menu_new();
 	menutree_build_shell(menu_tree, GTK_MENU_SHELL(submenu),
-		disable_shortcuts, 
 		_("_New Window"), MENUTREE_FILE_NEW_WINDOW,
 		_("New _Tab"), MENUTREE_FILE_NEW_TAB,
 		_("C_lose Tab"), MENUTREE_FILE_CLOSE_TAB,
@@ -449,7 +446,6 @@ static void menutree_build(MenuTree *menu_tree, Options *shortcuts,
 
 	submenu = gtk_menu_new();
 	menutree_build_shell(menu_tree, GTK_MENU_SHELL(submenu),
-		disable_shortcuts, 
 		_("_Copy"), MENUTREE_EDIT_COPY,
 		_("_Paste"), MENUTREE_EDIT_PASTE,
 		"_", MENUTREE_NULL_ID,
@@ -461,7 +457,6 @@ static void menutree_build(MenuTree *menu_tree, Options *shortcuts,
 
 	submenu = gtk_menu_new();
 	menutree_build_shell(menu_tree, GTK_MENU_SHELL(submenu),
-		disable_shortcuts, 
 		_("Show Menu_bar"), MENUTREE_VIEW_SHOW_MENUBAR,
 		_("_Full Screen"), MENUTREE_VIEW_FULLSCREEN,
 		"_", MENUTREE_NULL_ID,
@@ -477,7 +472,6 @@ static void menutree_build(MenuTree *menu_tree, Options *shortcuts,
 
 	submenu = gtk_menu_new();
 	menutree_build_shell(menu_tree, GTK_MENU_SHELL(submenu),
-		disable_shortcuts, 
 		_("Select _Profile"), MENUTREE_PREFERENCES_SELECT_PROFILE,
 		_("Select _Colour Scheme"), MENUTREE_PREFERENCES_SELECT_COLOUR_SCHEME,
 		_("Select _Shortcuts Scheme"), MENUTREE_PREFERENCES_SELECT_SHORTCUTS,
@@ -498,7 +492,6 @@ static void menutree_build(MenuTree *menu_tree, Options *shortcuts,
 
 	submenu = gtk_menu_new();
 	menutree_build_shell(menu_tree, GTK_MENU_SHELL(submenu),
-		disable_shortcuts, 
 		_("Na_me Tab..."), MENUTREE_TABS_NAME_TAB,
 		"_", MENUTREE_TABS_SEP1,
 		_("_Previous Tab"), MENUTREE_TABS_PREVIOUS_TAB,
@@ -508,7 +501,6 @@ static void menutree_build(MenuTree *menu_tree, Options *shortcuts,
 
 	submenu = gtk_menu_new();
 	menutree_build_shell(menu_tree, GTK_MENU_SHELL(submenu),
-		disable_shortcuts, 
 		_("Show _Manual"), MENUTREE_HELP_SHOW_MANUAL,
 		_("_About ROXTerm"), MENUTREE_HELP_ABOUT, NULL);
 	gtk_menu_item_set_submenu(GTK_MENU_ITEM(menu_tree->item_widgets
@@ -533,7 +525,8 @@ static void menutree_destroy_widget_handler(GtkObject * obj, MenuTree * tree)
 }
 
 MenuTree *menutree_new(Options *shortcuts, GtkAccelGroup *accel_group,
-	GType menu_type, gboolean disable_shortcuts, gpointer user_data)
+	GType menu_type, gboolean disable_shortcuts,
+	gboolean disable_tab_shortcuts, gpointer user_data)
 {
 	MenuTree *tree = g_new0(MenuTree, 1);
 
@@ -547,8 +540,9 @@ MenuTree *menutree_new(Options *shortcuts, GtkAccelGroup *accel_group,
 	tree->user_data = user_data;
 	tree->accel_group = accel_group;
 	tree->disable_shortcuts = disable_shortcuts;
+	tree->disable_tab_shortcuts = disable_tab_shortcuts;
 
-	menutree_build(tree, shortcuts, menu_type, disable_shortcuts);
+	menutree_build(tree, shortcuts, menu_type);
 
 	g_signal_connect(GTK_OBJECT(tree->top_level),
 		"destroy", G_CALLBACK(menutree_destroy_widget_handler), tree);
@@ -753,4 +747,12 @@ void menutree_disable_shortcuts(MenuTree *tree, gboolean disable)
 	}
 }
 
+void menutree_disable_tab_shortcuts(MenuTree *tree, gboolean disable)
+{
+	if (tree->disable_tab_shortcuts == disable)
+		return;
+	tree->disable_tab_shortcuts = disable;
+	menutree_apply_tab_shortcuts(tree);
+}
+	
 /* vi:set sw=4 ts=4 noet cindent cino= */
