@@ -1115,13 +1115,16 @@ static void multi_win_connect_actions(MultiWin * win)
 		(multi_win_scroll_down_action), win, NULL, NULL);
 }
 
-inline static void multi_win_show_tabs(MultiWin * win)
+static void multi_win_show_tabs(MultiWin * win)
 {
-	gtk_notebook_set_show_tabs(GTK_NOTEBOOK(win->notebook), TRUE);
-	gtk_notebook_set_show_border(GTK_NOTEBOOK(win->notebook), TRUE);
+	if (win->tab_pos != -1)
+	{
+		gtk_notebook_set_show_tabs(GTK_NOTEBOOK(win->notebook), TRUE);
+		gtk_notebook_set_show_border(GTK_NOTEBOOK(win->notebook), TRUE);
+	}
 }
 
-inline static void multi_win_hide_tabs(MultiWin * win)
+static void multi_win_hide_tabs(MultiWin * win)
 {
 	gtk_notebook_set_show_tabs(GTK_NOTEBOOK(win->notebook), FALSE);
 	gtk_notebook_set_show_border(GTK_NOTEBOOK(win->notebook), FALSE);
@@ -1139,8 +1142,11 @@ MultiWin *multi_win_new_blank(Options *shortcuts, int zoom_index,
 		gpointer user_data_template, GtkPositionType tab_pos)
 {
 	MultiWin *win = g_new0(MultiWin, 1);
-	gboolean disable_menu_shortcuts =
-			multi_win_get_disable_menu_shortcuts(user_data_template);
+	gboolean disable_menu_shortcuts, disable_tab_menu_shortcuts;
+	
+	multi_win_get_disable_menu_shortcuts(user_data_template,
+			&disable_menu_shortcuts, &disable_tab_menu_shortcuts);
+
 #if !DO_OWN_TAB_DRAGGING
 	static gboolean set_nwc_hook = FALSE;
 
@@ -1173,12 +1179,13 @@ MultiWin *multi_win_new_blank(Options *shortcuts, int zoom_index,
 	gtk_window_add_accel_group(GTK_WINDOW(win->gtkwin), win->accel_group);
 
 	win->popup_menu = menutree_new(shortcuts, win->accel_group,
-		GTK_TYPE_MENU, disable_menu_shortcuts, win);
+		GTK_TYPE_MENU, disable_menu_shortcuts, disable_tab_menu_shortcuts, win);
 	menutree_connect_destroyed(win->popup_menu,
 		G_CALLBACK(multi_win_menutree_deleted_handler), win);
 
 	win->menu_bar = menutree_new(shortcuts, win->accel_group,
-		GTK_TYPE_MENU_BAR, disable_menu_shortcuts, win);
+		GTK_TYPE_MENU_BAR, disable_menu_shortcuts, disable_tab_menu_shortcuts,
+		win);
 	/* Make sure menu widgets aren't destroyed when removed from window */
 	g_object_ref(menutree_get_top_level_widget(win->menu_bar));
 	menutree_connect_destroyed(win->menu_bar,
@@ -1228,7 +1235,10 @@ MultiWin *multi_win_new_full(Options *shortcuts, int zoom_index,
 		multi_tab_new(win, user_data_template);
 
 	gtk_notebook_set_current_page(GTK_NOTEBOOK(win->notebook), 0);
-	gtk_notebook_set_tab_pos(GTK_NOTEBOOK(win->notebook), tab_pos);
+	if (tab_pos == -1)
+		gtk_notebook_set_show_tabs(GTK_NOTEBOOK(win->notebook), FALSE);
+	else
+		gtk_notebook_set_tab_pos(GTK_NOTEBOOK(win->notebook), tab_pos);
 	multi_win_shade_menus_for_tabs(win);
 
 	if (geom)
