@@ -81,7 +81,8 @@ typedef void (*MultiWinZoomHandler)(gpointer user_data, double zoom_factor,
 		int zoom_index);
 
 /* Called to find out whether to use menu shortcuts */
-typedef gboolean (*MultiWinGetDisableMenuShortcuts)(gpointer user_data);
+typedef void (*MultiWinGetDisableMenuShortcuts)(gpointer user_data,
+	gboolean *general, gboolean *tabs);
 
 /* As number of tabs and tab position can be set by user we need another
  * function to get these values */
