@@ -488,6 +488,8 @@ static void profilegui_fill_in_dialog(ProfileGUI * pg)
 			DEFAULT_DELETE_BINDING);
 	capplet_set_boolean_toggle(glade, profile, "disable_menu_access", FALSE);
 	capplet_set_boolean_toggle(glade, profile, "disable_menu_shortcuts", FALSE);
+	capplet_set_boolean_toggle(glade, profile, "disable_tab_menu_shortcuts",
+			FALSE);
 	capplet_set_boolean_toggle(glade, profile, "login_shell", FALSE);
 	capplet_set_boolean_toggle(glade, profile, "update_records", TRUE);
 	capplet_set_boolean_toggle(glade, profile, "use_custom_command", FALSE);
