@@ -91,9 +91,11 @@ struct ROXTermData {
 	int hold_x, hold_y;		/* Position of event above */
 	gulong hold_handler_id;	/* Signal handler id for the above event */
 	char *encoding;
-	double zoom_factor;
+	double target_zoom_factor, current_zoom_factor;
 	int zoom_index;
 	PangoFontDescription *pango_desc;
+	char *title_template;	/*	Set if new terminal created by roxterm_launch
+								and --title was given. */
 };
 
 #define PROFILE_NAME_KEY "roxterm_profile_name"
@@ -278,6 +280,8 @@ static ROXTermData *roxterm_data_clone(ROXTermData *old_gt)
 	new_gt->tab = NULL;
 	new_gt->pango_desc = NULL;
 	new_gt->running = FALSE;
+	new_gt->title_template = NULL;
+	new_gt->current_zoom_factor = 1.0;
 	if (old_gt->colour_scheme)
 	{
 		new_gt->colour_scheme = colour_scheme_lookup_and_ref
@@ -758,23 +762,17 @@ roxterm_apply_colour_scheme(ROXTermData * roxterm, VteTerminal * vte)
 	const GdkColor *background = colour_scheme_get_background_colour
 		(roxterm->colour_scheme, FALSE);
 
-	if (!foreground && !background)
+	vte_terminal_set_default_colors(vte);
+	ncolours = colour_scheme_get_palette_size(roxterm->colour_scheme);
+	if (ncolours)
+		palette = colour_scheme_get_palette(roxterm->colour_scheme);
+	vte_terminal_set_colors(vte, foreground, background, palette, ncolours);
+	if (!ncolours && foreground && background)
 	{
-		vte_terminal_set_default_colors(vte);
-	}
-	else
-	{
-		ncolours = colour_scheme_get_palette_size(roxterm->colour_scheme);
-		if (ncolours)
-			palette = colour_scheme_get_palette(roxterm->colour_scheme);
-		vte_terminal_set_colors(vte, foreground, background, palette, ncolours);
-		if (!ncolours)
-		{
-			vte_terminal_set_color_bold(vte,
-					extrapolate_colours(background, foreground, 1.2));
-			vte_terminal_set_color_dim(vte,
-					extrapolate_colours(background, foreground, 0.7));
-		}
+		vte_terminal_set_color_bold(vte,
+				extrapolate_colours(background, foreground, 1.2));
+		vte_terminal_set_color_dim(vte,
+				extrapolate_colours(background, foreground, 0.7));
 	}
 	roxterm_update_cursor_colour(roxterm, vte, FALSE);
 	roxterm_force_redraw(vte);
@@ -879,9 +877,10 @@ roxterm_update_font(ROXTermData *roxterm, VteTerminal *vte,
 	PangoFontDescription *pango_desc = NULL;
 
 	fdesc = options_lookup_string(roxterm->profile, "font");
-	if (fdesc)
+	if (fdesc || roxterm->target_zoom_factor != roxterm->current_zoom_factor ||
+			update_geometry)
 	{
-		if (roxterm->zoom_factor == 1.0)
+		if (fdesc && roxterm->target_zoom_factor == 1.0)
 		{
 			vte_terminal_set_font_from_string(vte, fdesc);
 		}
@@ -889,8 +888,18 @@ roxterm_update_font(ROXTermData *roxterm, VteTerminal *vte,
 		{
 			int size;
 			gboolean abs = FALSE;
+			double zf = roxterm->target_zoom_factor;
 
-			pango_desc = pango_font_description_from_string(fdesc);
+			if (fdesc)
+			{
+				pango_desc = pango_font_description_from_string(fdesc);
+			}
+			else
+			{
+				pango_desc = pango_font_description_copy(
+						vte_terminal_get_font(vte));
+				zf /= roxterm->current_zoom_factor;
+			}
 			if (!pango_desc)
 			{
 				g_free(fdesc);
@@ -901,7 +910,7 @@ roxterm_update_font(ROXTermData *roxterm, VteTerminal *vte,
 				size = 10 * PANGO_SCALE;
 			else
 				abs = pango_font_description_get_size_is_absolute(pango_desc);
-			size = (int) ((double) size * roxterm->zoom_factor);
+			size = (int) ((double) size * zf);
 			if (abs)
 				pango_font_description_set_absolute_size(pango_desc, size);
 			else
@@ -913,6 +922,7 @@ roxterm_update_font(ROXTermData *roxterm, VteTerminal *vte,
 			pango_font_description_free(roxterm->pango_desc);
 		roxterm->pango_desc = pango_desc;
 	}
+	roxterm->current_zoom_factor = roxterm->target_zoom_factor;
 	if (update_geometry)
 		roxterm_update_geometry(roxterm, vte);
 }
@@ -920,8 +930,8 @@ roxterm_update_font(ROXTermData *roxterm, VteTerminal *vte,
 static void roxterm_set_zoom_factor(ROXTermData *roxterm, double factor,
 		int index)
 {
-	roxterm->zoom_factor = factor;
 	roxterm->zoom_index = index;
+	roxterm->target_zoom_factor = factor;
 	roxterm_update_font(roxterm, VTE_TERMINAL(roxterm->widget), TRUE);
 }
 
@@ -1853,9 +1863,17 @@ static void roxterm_apply_disable_menu_access(ROXTermData *roxterm)
 static void roxterm_apply_title_template(ROXTermData *roxterm)
 {
 	static char *bad_template = NULL;
-	char *tt = options_lookup_string_with_default(roxterm->profile,
+	char *tt = NULL;
+	
+	if (roxterm->title_template)
+	{
+		tt = g_strdup(roxterm->title_template);
+	}
+	else
+	{
+		tt = options_lookup_string_with_default(roxterm->profile,
 			"title_string", "%s");
-
+	}
 	if (tt && !multi_win_validate_title_template(tt))
 	{
 		if (!bad_template || strcmp(bad_template, tt))
@@ -1965,6 +1983,11 @@ static GtkWidget *roxterm_multi_tab_filler(MultiWin * win, MultiTab * tab,
 	int hide_menu_bar = global_options_lookup_int("hide_menubar");
 	MultiWinScrollBar_Position scrollbar_pos;
 
+	if ((!roxterm_template->win || roxterm_template->win == win)
+		&& roxterm_template->title_template)
+	{
+		roxterm->title_template = g_strdup(roxterm_template->title_template);
+	}
 	roxterm_terms = g_list_append(roxterm_terms, roxterm);
 
 	if (hide_menu_bar == -1)
@@ -2179,8 +2202,20 @@ static void roxterm_reflect_profile_change(Options * profile, const char *key)
 			mtree = multi_win_get_menu_bar(roxterm->win);
 			menutree_disable_shortcuts(mtree, disable);
 		}
+		else if (!strcmp(key, "disable_tab_menu_shortcuts"))
+		{
+			gboolean disable = options_lookup_int(roxterm->profile,
+					"disable_tab_menu_shortcuts");
+			MenuTree *mtree = multi_win_get_popup_menu(roxterm->win);
+
+			menutree_disable_tab_shortcuts(mtree, disable);
+			mtree = multi_win_get_menu_bar(roxterm->win);
+			menutree_disable_tab_shortcuts(mtree, disable);
+		}
 		else if (!strcmp(key, "title_string"))
 		{
+			g_free(roxterm->title_template);
+			roxterm->title_template = NULL;
 			roxterm_apply_title_template(roxterm);
 		}
 	}
@@ -2514,6 +2549,8 @@ static GtkPositionType roxterm_get_tab_pos(const ROXTermData *roxterm)
 			return GTK_POS_LEFT;
 		case 3:
 			return GTK_POS_RIGHT;
+		case 4:
+			return -1;
 		default:
 			return GTK_POS_TOP;
 	}
@@ -2538,16 +2575,17 @@ void roxterm_launch(void)
 	gboolean size_on_cli = FALSE;
 	int numtabs;
 
-	roxterm->zoom_factor = global_options_lookup_double("zoom");
-	if (!roxterm->zoom_factor)
+	roxterm->title_template = global_options_lookup_string("title");
+	roxterm->target_zoom_factor = global_options_lookup_double("zoom");
+	if (!roxterm->target_zoom_factor)
 	{
-		roxterm->zoom_factor = 1.0;
+		roxterm->target_zoom_factor = 1.0;
 		roxterm->zoom_index = -1;
 	}
 	else
 	{
 		roxterm->zoom_index = multi_win_get_nearest_index_for_zoom(
-				roxterm->zoom_factor);
+				roxterm->target_zoom_factor);
 	}
 	if (global_options_commandv)
 		roxterm->commandv = global_options_copy_strv(global_options_commandv);
@@ -2707,10 +2745,19 @@ static void roxterm_tab_to_new_window(MultiWin *win, MultiTab *tab)
 	}
 }
 
-static gboolean roxterm_get_disable_menu_shortcuts(ROXTermData *roxterm)
+static void roxterm_get_disable_menu_shortcuts(ROXTermData *roxterm,
+	gboolean *general, gboolean *tabs)
 {
-	return options_lookup_int_with_default(roxterm->profile,
+	if (general)
+	{
+		*general = options_lookup_int_with_default(roxterm->profile,
 			"disable_menu_shortcuts", FALSE);
+	}
+	if (tabs)
+	{
+		*tabs = options_lookup_int_with_default(roxterm->profile,
+			"disable_tab_menu_shortcuts", FALSE);
+	}
 }
 
 void roxterm_init(void)
